@@ -29,6 +29,7 @@
 
 #include <libxfce4ui/xfce-gdk-extensions.h>
 #include <libxfce4ui/libxfce4ui-private.h>
+#include <libxfce4ui/libxfce4ui-alias.h>
 
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
@@ -100,3 +101,8 @@ out:
   return gdk_screen_get_default ();
 #endif
 }
+
+
+
+#define __XFCE_GDK_EXTENSIONS_C__
+#include <libxfce4ui/libxfce4ui-aliasdef.c>
